@@ -23,12 +23,17 @@
 template<typename T1, typename T2>
 arma_warn_unused
 inline
-const Glue<T1, T2, glue_cross>
-cross(const Base<typename T1::elem_type,T1>& X, const Base<typename T1::elem_type,T2>& Y)
+typename
+enable_if2
+  <
+  is_arma_type<T1>::value && is_arma_type<T2>::value && is_same_type<typename T1::elem_type, typename T2::elem_type>::value,
+  const Glue<T1, T2, glue_cross>
+  >::result
+cross(const T1& X, const T2& Y)
   {
   arma_extra_debug_sigprint();
   
-  return Glue<T1, T2, glue_cross>(X.get_ref(), Y.get_ref());
+  return Glue<T1, T2, glue_cross>(X, Y);
   }
 
 
